"""
This module implements text steganography
Author: Atharva Vidwans
Github: https://github.com/Atharva-Vidwans
LinkedIn: https://www.linkedin.com/in/atharva-vidwans-62739b169/
Medium: https://medium.com/@atharvavidwans
Website: https://atharva-vidwans.github.io/Website/ 

"""

__author__ = "Atharva Vidwans"
__email__ = "atharvavidwans@gmail.com"
__status__ = "stable"
__version__= "0.0.8" 

from TextStega.stg import TextStega 